@@ -16,10 +16,10 @@ sub parse_arg {
 }
 
 sub _verify {
-    my ($depot, $sig, $chg) = @_;
-    my $fs = $depot->repos->fs;
-    my $editor = SVK::VerifyEditor->new ({ sig => $sig,
-					   depot => $depot });
+    my ($repos, $sig, $chg) = @_;
+    my $fs = $repos->fs;
+    my $editor = SVK::VerifyEditor->new ( sig => $sig,
+					  repos => $repos );
 
     # should really just use paths_changed
     SVN::Repos::dir_delta ($fs->revision_root ($chg-1), '/', '',
@@ -36,9 +36,9 @@ sub _verify {
 sub run {
     my ($self, $chg, $depot) = @_;
     my $target = $self->arg_depotpath ("/$depot/");
-    my $fs = $target->repos->fs;
+    my $fs = $target->{repos}->fs;
     my $sig = $fs->revision_prop ($chg, 'svk:signature');
-    return _verify($target->depot, $sig, $chg)
+    return _verify ($target->{repos}, $sig, $chg)
 	if $sig;
     print "No signature found for change $chg at /$depot/.\n";
     return;
@@ -46,8 +46,9 @@ sub run {
 
 # XXX: Don't need this editor once root->paths_changed is available.
 package SVK::VerifyEditor;
-use base 'SVK::Editor';
-__PACKAGE__->mk_accessors(qw(depot sig));
+use autouse 'SVK::Util' => qw(resolve_svm_source);
+require SVN::Delta;
+our @ISA = ('SVN::Delta::Editor');
 
 sub add_file {
     my ($self, $path, @arg) = @_;
@@ -66,7 +67,7 @@ sub close_file {
 
 sub close_edit {
     my ($self, $baton) = @_;
-    my $sig = $self->sig;
+    my $sig = $self->{sig};
     local *D;
     # verify the signature
     my $pgp = $ENV{SVKPGP} || 'gpg';
@@ -83,9 +84,7 @@ sub close_edit {
     my $header = '-----BEGIN PGP SIGNED MESSAGE-----';
     $sig =~ s/^.*$header/$header/s;
     my ($anchor) = $sig =~ m/^ANCHOR: (.*)$/m;
-    my ($path) = $self->depot->find_local_mirror(split(':', $anchor));
-    $path ||= (split(':', $anchor))[1];
-
+    my ($path) = resolve_svm_source ($self->{repos}, split (':', $anchor));
     while ($sig =~ m/^MD5\s(.*?)\s(.*?)$/gm) {
 	my ($md5, $filename) = ($1, $2);
 	my $checksum = delete $self->{checksum}{"$path/$filename"};
